# textrepo-client

[![GitHub Actions](https://github.com/knaw-huc/textrepo-client-python/workflows/tests/badge.svg)](https://github.com/knaw-huc/textrepo-client-python/actions)
[![Project Status: Active – The project has reached a stable, usable state and is being actively developed.](https://www.repostatus.org/badges/latest/active.svg)](https://www.repostatus.org/#active)
![PyPI](https://img.shields.io/pypi/v/textrepo-client)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/textrepo-client)

A Python client for accessing a [textrepo](https://github.com/knaw-huc/textrepo) server

# installing

### using poetry

```commandline
poetry add annorepo-client
```

### using pip

```commandline
pip install annorepo-client
```

----

[USAGE](USAGE.md) |
[CONTRIBUTING](CONTRIBUTING.md)